@@ -23,17 +23,30 @@ class LocalExecutionIntegration():
     
         return cmd
 
+    def __normalize_path(self, path):
+        beheaded_path = path if not str(path).startswith('$PWD') else str(path)[4:]
+        beheaded_path = os.path.abspath(".") if len(beheaded_path) == 0 or beheaded_path in ['/', '.'] else \
+            beheaded_path[0].replace('/', '') + beheaded_path[1:]
+        return beheaded_path
+
     def construct_verbosity_output(self, input_dir, output_dir, image, command, original_args):
-        tira_run_input_dir = input_dir if not str(input_dir) == str(os.path.abspath(".")) else None
-        tira_run_output_dir = output_dir if not str(output_dir) == str(os.path.abspath("tira-output")) else None
-        tira_run_args = [(k, v if type(v) is not str else f'"{v}"') for k, v in original_args.items()]
-        tira_run_args = [i.strip() for i in ['' if not original_args[k] else f'{k}={v}' for k, v in tira_run_args] if i]
+        beheaded_input_dir = self.__normalize_path(input_dir)
+        beheaded_output_dir = self.__normalize_path(output_dir)
+        tira_run_input_dir = beheaded_input_dir if not str(beheaded_input_dir) == str(os.path.abspath(".")) else None
+        tira_run_output_dir = beheaded_output_dir if not str(beheaded_output_dir) == str(os.path.abspath("tira-output")) else None
+        tira_run_python_args = {k: v for k, v in original_args.items()}
+        if type(tira_run_python_args['input_dir']) is str and tira_run_python_args['input_dir'].startswith('$PWD'):
+            tira_run_python_args['input_dir'] = self.__normalize_path(tira_run_python_args['input_dir'])
+        if type(tira_run_python_args['output_dir']) is str and tira_run_python_args['output_dir'].startswith('$PWD'):
+            tira_run_python_args['output_dir'] = self.__normalize_path(tira_run_python_args['output_dir'])
+        tira_run_args = [(k, v if type(v) is not str else f'"{v}"') for k, v in tira_run_python_args.items()]
+        tira_run_args = [i.strip() for i in ['' if not tira_run_python_args[k] else f'{k}={v}' for k, v in tira_run_args] if i]
     
         return {
             'tira-run-cli': f'tira-run ' + 
                 ('' if not tira_run_input_dir else f'--input-directory {tira_run_input_dir} ') +
                 ('' if not tira_run_output_dir else f'--output-directory {tira_run_output_dir} ') + 
-                (f'--approach {original_args["identifier"]} ' if 'identifier' in original_args else f'--image {image} --command \'{original_args["command"]}\''),
+                (f'--approach {original_args["identifier"]} ' if 'identifier' in original_args and original_args['identifier'] is not None else f'--image {image} --command \'{original_args["command"]}\''),
 
             'tira-run-python': 'tira.run(' + 
                 (', '.join(tira_run_args))
@@ -42,7 +55,7 @@ class LocalExecutionIntegration():
             'docker': f'docker run --rm -ti -v {input_dir}:/tira-data/input:ro -v {output_dir}:/tira-data/output:rw --entrypoint sh {image} -c \'{command}\''
         }
 
-    def run(self, identifier=None, image=None, command=None, input_dir=None, output_dir=None, evaluate=False, verbose=False, dry_run=False, docker_software_id_to_output=None, software_id=None):
+    def run(self, identifier=None, image=None, command=None, input_dir=None, output_dir=None, evaluate=False, verbose=False, dry_run=False, docker_software_id_to_output=None, software_id=None, allow_network=False):
         previous_stages = []
         original_args = {'identifier': identifier, 'image': image, 'command': command, 'input_dir': input_dir, 'output_dir': output_dir, 'evaluate': evaluate, 'verbose': verbose, 'dry_run': dry_run, 'docker_software_id_to_output': docker_software_id_to_output, 'software_id': software_id}
         s_id = 'unknown-software-id'
@@ -63,8 +76,8 @@ class LocalExecutionIntegration():
         if not input_dir or not output_dir:
             raise ValueError('please pass input_dir and output_dir')
     
-        input_dir = os.path.abspath(input_dir)
-        output_dir = os.path.abspath(output_dir)
+        input_dir = os.path.abspath(input_dir) if not str(input_dir).startswith('$PWD') else input_dir
+        output_dir = os.path.abspath(output_dir) if not str(output_dir).startswith('$PWD') else output_dir
     
         docker_software_id_to_output = {} if not docker_software_id_to_output else deepcopy(docker_software_id_to_output)
 
@@ -95,7 +108,7 @@ class LocalExecutionIntegration():
         for k, v in docker_software_id_to_output.items():
             volumes[str(os.path.abspath(v))] = {'bind': '/tira-data/input-run', 'mode': 'ro'}
 
-        container = client.containers.run(image, entrypoint='sh', command=f'-c "{command}"', volumes=volumes, detach=True, remove=True)
+        container = client.containers.run(image, entrypoint='sh', command=f'-c "{command}"', volumes=volumes, detach=True, remove=True, network_disabled = not allow_network)
 
         for line in container.attach(stdout=True, stream=True, logs=True):
             print(line.decode('utf-8'), flush=True)
